@@ -4,7 +4,7 @@ Keytotext converts a list of Keywords to sentences and larger texts
 """
 
 
-__version__ = "1.3.3"
+__version__ = "1.3.5"
 
 from .pipeline import pipeline
-from .trainer import KeytotextTrainer
+from .trainer import trainer
